@@ -3,7 +3,6 @@ from graphviz import Digraph
 from IPython.display import display
 from networkx.readwrite import json_graph
 from urllib.parse import quote
-import fnmatch
 import json
 import networkx as nx
 
@@ -717,14 +716,15 @@ class ER:
             label = label.partition("*")[0]
         obj_list = []
         for obj in list(self.get_graph().nodes(data=True)):
-            if ( node_type == NodeType.NOT_SPECIFIED or obj[1]["nodeType"] == str(node_type) ):
+            if ( node_type == NodeType.NOT_SPECIFIED or obj[1].get("nodeType", NodeType.NOT_SPECIFIED) == str(node_type) ):
+                obj_label = obj[1].get("label", "")
                 if label == "": 
                     obj_list.append(obj[1]) # get all nodes of this type
                 if label.endswith("."):
                     #print("wildcard" + label)
-                    if obj[1]["label"].startswith(label):
+                    if obj_label.startswith(label):
                         obj_list.append(obj[1])
-                if obj[1]["label"] == label:
+                if obj_label == label:
                     return obj[1]
         return obj_list
 
